;; Generated package description from inspector.el  -*- no-byte-compile: t -*-
(define-package "inspector" "0.38.0.20240911.94847" "Tool for inspection of Emacs Lisp objects" '((emacs "27.1")) :commit "c5617289dd40efb45f8160420c29000c7d7489de" :authors '(("Mariano Montone" . "marianomontone@gmail.com")) :maintainer '("Mariano Montone" . "marianomontone@gmail.com") :keywords '("debugging" "tool" "lisp" "development") :url "https://github.com/mmontone/emacs-inspector")
